@@ -15,6 +15,7 @@ class DirectAutoSizer(DirectFrame):
     A frame to Automatically resize the given other DirectGui element
     """
     def __init__(self, parent = None, child = None, **kw):
+        self.skipInitRefresh = True
         optiondefs = (
             ('extendHorizontal', True,      None),
             ('extendVertical',   True,      None),
@@ -23,7 +24,7 @@ class DirectAutoSizer(DirectFrame):
             ('updateOnWindowResize', True,  self.setUpdateOnWindowResize),
             ('childUpdateSizeFunc', None,   None),
             ('parentGetSizeFunction', None, None),
-            ('parentGetSizeExtraArgs', None, None),
+            ('parentGetSizeExtraArgs', [], None),
 
             ('suppressMouse',  0,           None),
             )
@@ -41,6 +42,10 @@ class DirectAutoSizer(DirectFrame):
         # Call option initialization functions
         self.initialiseoptions(DirectAutoSizer)
 
+        self.skipInitRefresh = False
+        # initialize once at the end
+        self.refresh()
+
     def setChild(self, child):
         if self.child is not None:
             self.child.detachNode()
@@ -68,15 +73,17 @@ class DirectAutoSizer(DirectFrame):
             # This event isn't about our window.
             return
 
-        #if window is not None: # window is none if panda3d is not started
-        #    if self.screenSize == base.getSize():
-        #        return
-        #self.screenSize = base.getSize()
-        taskMgr.doMethodLater(0.25, self.refresh, "delayed sizer refresh", extraArgs=[])
-        #self.refresh()
+        if self.screenSize == base.getSize():
+            return
+        self.screenSize = base.getSize()
+        self.refresh()
+
+        #TODO: for some reason, the first refresh doesn't always refresh everything correct, so we do it twice here
+        self.refresh()
 
     def refresh(self):
         """Resize the sizer and its child element"""
+        if self.skipInitRefresh: return
         if self.child is None:
             return
 
@@ -143,8 +150,8 @@ class DirectAutoSizer(DirectFrame):
             r = childSize[1] * childScale.getX()
 
         if not self['extendVertical']:
-            b = childSize[2] * childScale.getY()
-            t = childSize[3] * childScale.getY()
+            b = childSize[2] * childScale.getZ()
+            t = childSize[3] * childScale.getZ()
 
         #TODO: Better check for positive/negative numbers
         if l > self['minSize'][0]: l = self['minSize'][0]
@@ -165,9 +172,12 @@ class DirectAutoSizer(DirectFrame):
         t += self.child.getZ()
 
         # actual resizing of our child element
-        self.child["frameSize"] = [l/childScale.getX(),r/childScale.getX(),b/childScale.getY(),t/childScale.getY()]
+        self.child["frameSize"] = [l/childScale.getX(),r/childScale.getX(),b/childScale.getZ(),t/childScale.getZ()]
         self["frameSize"] = self.child["frameSize"]
 
-        base.messenger.send(self.uniqueName("update-size"))
+        base.messenger.send(self.getUpdateSizeEvent())
         if self['childUpdateSizeFunc'] is not None:
             self['childUpdateSizeFunc']()
+
+    def getUpdateSizeEvent(self):
+        return self.uniqueName("update-size")
